@@ -1,9 +1,11 @@
+use strict;
+use warnings;
 package Net::SAML2::Binding::SOAP;
 use Moose;
 use MooseX::Types::URI qw/ Uri /;
 use Net::SAML2::XML::Util qw/ no_comments /;
 
-our $VERSION = '0.45';
+our $VERSION = '0.46';
 
 # ABSTRACT: Net::SAML2::Binding::Artifact - SOAP binding for SAML
 
@@ -170,7 +172,7 @@ Net::SAML2::Binding::SOAP - Net::SAML2::Binding::Artifact - SOAP binding for SAM
 
 =head1 VERSION
 
-version 0.45
+version 0.46
 
 =head1 SYNOPSIS
 
