@@ -1,8 +1,10 @@
+use strict;
+use warnings;
 package Net::SAML2::IdP;
 use Moose;
 use MooseX::Types::URI qw/ Uri /;
 
-our $VERSION = '0.45';
+our $VERSION = '0.46';
 
 # ABSTRACT: Net::SAML2::IdP - SAML Identity Provider object
 
@@ -244,7 +246,7 @@ Net::SAML2::IdP - Net::SAML2::IdP - SAML Identity Provider object
 
 =head1 VERSION
 
-version 0.45
+version 0.46
 
 =head1 SYNOPSIS
 
