@@ -1,10 +1,12 @@
+use strict;
+use warnings;
 package Net::SAML2::Protocol::ArtifactResolve;
 use Moose;
 use MooseX::Types::URI qw/ Uri /;
 
 with 'Net::SAML2::Role::ProtocolMessage';
 
-our $VERSION = '0.45';
+our $VERSION = '0.46';
 
 # ABSTRACT: Net::SAML2::Protocol::ArtifactResolve - ArtifactResolve protocol class
 
@@ -57,7 +59,7 @@ Net::SAML2::Protocol::ArtifactResolve - Net::SAML2::Protocol::ArtifactResolve -
 
 =head1 VERSION
 
-version 0.45
+version 0.46
 
 =head1 SYNOPSIS
 
